@@ -29,68 +29,28 @@
 #' @keywords array iteration robust univar
 #' @export
 rowOrderStats <- function(x, rows = NULL, cols = NULL, which,
-                          dim. = dim(x), ..., useNames = NA) {
-  dim. <- as.integer(dim.)
+                          dim. = dim(x), ..., useNames = TRUE) {
 
   # Check missing values
   if (anyMissing(x)) {
     stop(sprintf("Argument '%s' must not contain missing values", "x"))
   }
 
-  which <- as.integer(which)
-  res <- .Call(C_rowOrderStats, x, dim., rows, cols, which)
-  
-  # Update names attribute?
-  if (!is.na(useNames)) {
-    if (useNames) {
-      names <- rownames(x)
-      if (!is.null(names)) {
-        if (!is.null(rows)) {
-          names <- names[rows]
-          # Zero-length attribute? Keep behavior same as base R function
-          if (length(names) == 0L) names <- NULL
-        }
-        names(res) <- names
-      }
-    } else {
-      names(res) <- NULL
-    }
-  }
-  
-  res
+  if (is.na(useNames)) deprecatedUseNamesNA()
+  .Call(C_rowOrderStats, x, dim., rows, cols, which, useNames)
 }
 
 
 #' @rdname rowOrderStats
 #' @export
 colOrderStats <- function(x, rows = NULL, cols = NULL, which,
-                          dim. = dim(x), ..., useNames = NA) {
-  dim. <- as.integer(dim.)
+                          dim. = dim(x), ..., useNames = TRUE) {
 
   # Check missing values
   if (anyMissing(x)) {
     stop(sprintf("Argument '%s' must not contain missing values", "x"))
   }
 
-  which <- as.integer(which)
-  res <- .Call(C_colOrderStats, x, dim., rows, cols, which)
-  
-  # Update names attribute?
-  if (!is.na(useNames)) {
-    if (useNames) {
-      names <- colnames(x)
-      if (!is.null(names)) {
-        if (!is.null(cols)) {
-          names <- names[cols]
-          # Zero-length attribute? Keep behavior same as base R function
-          if (length(names) == 0L) names <- NULL         
-        }
-        names(res) <- names
-      }
-    } else {
-      names(res) <- NULL
-    }
-  }
-  
-  res
+  if (is.na(useNames)) deprecatedUseNamesNA()
+  .Call(C_colOrderStats, x, dim., rows, cols, which, useNames)
 }
